snacknload library

Enums

ButtonSize
ButtonVariant
IndicatorType
Loading indicator type. see https://github.com/jogboms/flutter_spinkit#-showcase
LoadingStatus
Loading status
LoadingStyle
Loading style
MaskType
Loading mask type none default mask type, allow user interactions while loading is displayed clear don't allow user interactions while loading is displayed black don't allow user interactions while loading is displayed custom while mask type is custom, maskColor should not be null
SnackNLoadAnimationStyle
Loading animation
SnackNLoadPosition
Toast/Snackbar position
SnackNLoadType
Toast/Snackbar type

Typedefs

LoadingStatusCallback = void Function(LoadingStatus status)